@@ -17,14 +17,15 @@ cohort_table_day <- function(df, id_var, date) {
   dt <- dtplyr::lazy_dt(df)
 
   dt %>%
-    dplyr::group_by({{id_var}}) %>%
+    dplyr::rename(id = {{id_var}}) %>%
+    dplyr::group_by(id) %>%
     dplyr::mutate(cohort = min({{date}})) %>%
     dplyr::group_by(cohort, {{date}}) %>%
-    dplyr::summarise(users = dplyr::n()) %>%
+    dplyr::summarise(users = dplyr::n_distinct(id)) %>%
     tidyr::pivot_wider(names_from={{date}},values_from=users) %>%
     dplyr::ungroup() %>%
     dplyr::mutate(cohort = 1:dplyr::n_distinct(cohort)) %>%
     tibble::as_tibble()
 }
 
-utils::globalVariables(c("cohort","users"))
+utils::globalVariables(c("id","cohort","users"))
