@@ -17,15 +17,16 @@ cohort_table_month <- function(df, id_var, date) {
   dt <- dtplyr::lazy_dt(df)
 
   dt %>%
-    dplyr::group_by({{id_var}}) %>%
+    dplyr::rename(id = {{id_var}}) %>%
+    dplyr::group_by(id) %>%
     dplyr::mutate(month = zoo::as.yearmon({{date}})) %>%
     dplyr::mutate(cohort = min(month)) %>%
     dplyr::group_by(cohort, month) %>%
-    dplyr::summarise(users = dplyr::n()) %>%
+    dplyr::summarise(users = dplyr::n_distinct(id)) %>%
     tidyr::pivot_wider(names_from=month,values_from=users) %>%
     dplyr::ungroup() %>%
     dplyr::mutate(cohort = 1:dplyr::n_distinct(cohort)) %>%
     tibble::as_tibble()
 }
 
-utils::globalVariables(c("cohort","users","month","%>%"))
+utils::globalVariables(c("id","cohort","users","month","%>%"))
